#!/bin/bash

# Frissítsük a csomaglistát
echo "Csomaglista frissítése..."
sudo pacman -Syu --noconfirm

# Nano és Bash-completion telepítése
echo "Csomagok telepítése..."
sudo pacman -S --noconfirm nano bash-completion spice-vdagent git


# pacman.conf helyének meghatározása
PACMAN_CONF="/etc/pacman.conf"

# Ellenőrizzük, hogy a fájl létezik-e
if [[ ! -f $PACMAN_CONF ]]; then
  echo "Az $PACMAN_CONF fájl nem található."
  exit 1
fi

# Távolítsuk el a '#' jelet a szükséges sorok elejéről
sed -i 's/^#ParallelDownloads = 5/ParallelDownloads = 5/' "$PACMAN_CONF"
sed -i 's/^#Color/Color/' "$PACMAN_CONF"

# Ellenőrizzük, hogy a ParallelDownloads sor sikeresen frissült-e
if ! grep -q "^ParallelDownloads = 5" "$PACMAN_CONF"; then
  echo "Nem sikerült frissíteni a #ParallelDownloads = 5 sort. A script leáll."
  exit 1
fi

# Adjunk hozzá egy ILoveCandy sort a ParallelDownloads sor alá
sed -i '/^ParallelDownloads = 5/a ILoveCandy' "$PACMAN_CONF"

# Ellenőrizzük, hogy a ILoveCandy sor sikeresen bekerült-e
if ! grep -q "^ILoveCandy" "$PACMAN_CONF"; then
  echo "Nem sikerült hozzáadni az ILoveCandy sort. A script leáll."
  exit 1
fi

# Ellenőrizzük, hogy a Color sor sikeresen frissült-e
if ! grep -q "^Color" "$PACMAN_CONF"; then
  echo "Nem sikerült frissíteni a #Color sort. A script leáll."
  exit 1
fi

echo "A módosítások sikeresen megtörténtek: #ParallelDownloads = 5 frissítve, ILoveCandy hozzáadva, #Color frissítve."


# Grub fájl helye
GRUB_DEFAULT="/etc/default/grub"

# Ellenőrizzük, hogy a fájl létezik-e
if [[ ! -f $GRUB_DEFAULT ]]; then
  echo "Az $GRUB_DEFAULT fájl nem található."
  exit 1
fi

# Ellenőrizzük, hogy a GRUB_TIMEOUT_STYLE sor már létezik-e
if grep -q "^GRUB_TIMEOUT_STYLE=hidden" "$GRUB_DEFAULT"; then
  echo "A GRUB_TIMEOUT_STYLE=hidden már szerepel az $GRUB_DEFAULT fájlban."
else
  # Adjuk hozzá a sort a fájl végéhez
  echo "GRUB_TIMEOUT_STYLE=hidden" >> "$GRUB_DEFAULT"
  echo "A GRUB_TIMEOUT_STYLE=hidden hozzáadva az $GRUB_DEFAULT fájlhoz."
fi

# Futtassuk a grub-mkconfig parancsot
if grub-mkconfig -o /boot/grub/grub.cfg; then
  echo "A GRUB konfiguráció sikeresen frissítve."
else
  echo "Nem sikerült frissíteni a GRUB konfigurációt."
  exit 1
fi
